tietools.label_tie_chains_in_expr_with_tie_chain_durations
==========================================================

.. autofunction:: abjad.tools.tietools.label_tie_chains_in_expr_with_tie_chain_durations.label_tie_chains_in_expr_with_tie_chain_durations
